@@ -24,7 +24,7 @@ class SendGridClient(object):
     values['to[]'] = message.to
     values['toname[]'] = message.to_name
     values['from'] = message.from_email
-    values['from_name'] = message.from_name
+    values['fromname'] = message.from_name
     values['subject'] = message.subject
     values['text'] = message.text
     values['html'] = message.html
